package com.huiju.welcome.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.welcome.common.base.BaseController;
import com.huiju.welcome.common.base.ResponseBean;
import com.huiju.welcome.model.TaGoods;
import com.huiju.welcome.model.TaGoodsSpec;
import com.huiju.welcome.service.ITaGoodsService;
import com.huiju.welcome.service.ITaGoodsSpecService;
import com.huiju.welcome.utils.JWTUtils;
import com.huiju.welcome.utils.StatusUtils;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;


/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-16
 */
@RestController
@RequestMapping("/")
public class TaGoodsController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaGoodsController.class);

    @Autowired
    public ITaGoodsService iTaGoodsService;
    @Autowired
    public ITaGoodsSpecService iTaGoodsSpecService;


    /**
     * 保存对象
     * @param taGoods 实体对象
     * @return
     */
    @RequestMapping(value="/taGoods/add",method= RequestMethod.POST)
    public ResponseBean taGoodsAdd(@RequestBody TaGoods taGoods, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            taGoods.setCreateDate(LocalDateTime.now());
            taGoods.setStatus(StatusUtils.Normal);
            String userId = JWTUtils.getSubject(request);
            taGoods.setCreateUser(userId);
            Boolean flag = iTaGoodsService.save(taGoods);
            List<TaGoodsSpec> specList = taGoods.getSpecList();
            specList.stream().forEach(e -> {
                e.setGoodsId(taGoods.getGoodsId());
                e.setGoodsPrice(BigDecimal.valueOf(0));
            });

            boolean result = iTaGoodsSpecService.saveBatch(specList);

            if (flag&&result){
                responseBean.addSuccess(taGoods);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taGoodsAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taGoods/delete/{id}", method= RequestMethod.DELETE)
    public ResponseBean taGoodsDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            TaGoods taGoods = iTaGoodsService.getById(id);
            taGoods.setStatus(StatusUtils.Delete);
            if(iTaGoodsService.updateById(taGoods)){
                responseBean.addSuccess("success");
                iTaGoodsSpecService.deleteSpecsByGoodsId(taGoods.getGoodsId());
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taGoodsDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param taGoods 实体对象
     * @return
     */
    @RequestMapping(value="/taGoods/update",method= RequestMethod.PUT)
    public ResponseBean taGoodsUpdate(@RequestBody TaGoods taGoods){
        ResponseBean responseBean = new ResponseBean();
        try {
            Boolean flag = iTaGoodsService.updateById(taGoods);
            iTaGoodsSpecService.deleteSpecsByGoodsId(taGoods.getGoodsId());
            Boolean flagSpec = false;
            List<TaGoodsSpec> specList = taGoods.getSpecList();
            specList.stream().forEach(e -> {
                e.setGoodsId(taGoods.getGoodsId());
                e.setGoodsPrice(BigDecimal.valueOf(0));
            });
            flagSpec = iTaGoodsSpecService.saveBatch(specList);
            if (flag&& flagSpec){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taGoodsUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taGoods/get/{id}",method= RequestMethod.GET)
    public ResponseBean taGoodsGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            TaGoods taGoods = iTaGoodsService.getById(id);
            taGoods.setSpecList(iTaGoodsSpecService.specListByGoodsId(id));
            responseBean.addSuccess(taGoods);
        }catch (Exception e){
            logger.error("taGoodsDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    @ApiOperation(value = "商品列表", notes = "商品列表")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/taGoods", method = RequestMethod.GET)
    public ResponseBean goodsList(@RequestParam(defaultValue = "1") int pageNum,
                                 @RequestParam(defaultValue = "10") int pageSize,
                                 @RequestParam(value = "goodsName",required = false) String goodsName,
                                 @RequestParam(value = "typeId",required = false) Integer typeId) {
        IPage<TaGoods> pg = new Page<>(pageNum, pageSize);

        ResponseBean userManagement= iTaGoodsService.goodsList(pg,goodsName,typeId);

        return userManagement;
    }

    @ApiOperation(value = "商品列表", notes = "商品列表")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/miniapp/taGoods", method = RequestMethod.GET)
    public ResponseBean goodsListForMiniApp(@RequestParam(defaultValue = "1") int pageNum,
                                 @RequestParam(defaultValue = "10") int pageSize,
                                 @RequestParam(value = "goodsName",required = false) String goodsName,
                                 @RequestParam(value = "typeId",required = false) Integer typeId) {
        IPage<TaGoods> pg = new Page<>(pageNum, pageSize);

        ResponseBean userManagement= iTaGoodsService.goodsList(pg,goodsName,typeId);

        return userManagement;
    }






}
